==> kdesdk-4.6.3.tar.bz2: kdesdk-4.6.3/okteta/libs/kasten/controllers/documentsystem/documentsbrowser/documentstoolview.h <==
/*
    This file is part of the Kasten Framework, part of the KDE project.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef DOCUMENTSTOOLVIEW_H
#define DOCUMENTSTOOLVIEW_H

// lib
#include "kastencontrollers_export.h"
// Kasten gui
#include <abstracttoolview.h>


namespace Kasten
{

class DocumentsView;
class DocumentsTool;


class KASTENCONTROLLERS_EXPORT DocumentsToolView : public AbstractToolView
{
  public:
    explicit DocumentsToolView( DocumentsTool* tool );
    virtual ~DocumentsToolView();

  public: // AbstractToolView API
    virtual QWidget* widget() const;
    virtual QString title() const;
    virtual AbstractTool* tool() const;

  protected:
    DocumentsView* mWidget;
};

}

#endif

==> kdesdk-4.7.0.tar.bz2: kdesdk-4.7.0/okteta/libs/kasten/controllers/documentsystem/documentsbrowser/documentstoolview.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef DOCUMENTSTOOLVIEW_H
#define DOCUMENTSTOOLVIEW_H

// lib
#include "kastencontrollers_export.h"
// Kasten gui
#include <abstracttoolview.h>


namespace Kasten
{

class DocumentsView;
class DocumentsTool;


class KASTENCONTROLLERS_EXPORT DocumentsToolView : public AbstractToolView
{
  public:
    explicit DocumentsToolView( DocumentsTool* tool );
    virtual ~DocumentsToolView();

  public: // AbstractToolView API
    virtual QWidget* widget() const;
    virtual QString title() const;
    virtual AbstractTool* tool() const;

  protected:
    DocumentsView* mWidget;
};

}

#endif
